measuretools.move_prolation_of_full_measure_tuplet_to_meter_of_measure
======================================================================

.. autofunction:: abjad.tools.measuretools.move_prolation_of_full_measure_tuplet_to_meter_of_measure.move_prolation_of_full_measure_tuplet_to_meter_of_measure
